# jsb/imports.py
#
#

""" provide a import wrappers for the contrib packages. """

## lib imports

from jsb.lib.jsbimport import _import

## basic imports

import logging

## getdns function

def getsleekxmpp():
    try:
        mod = _import("sleekxmpp")
    except: mod = _import("boty.contrib.sleekxmpp")
    logging.debug("imports - sleekxmpp module is %s" % str(mod))
    return mod



# boty/drivers/xmpp/bot.py
#
#

""" XMPP bot build on sleekxmpp. """

## boty imports

from boty.imports import getsleekxmpp

sleekxmpp = getsleekxmpp()

## jsb imports

from jsb.utils.xmpp import stripped
from jsb.lib.botbase import BotBase
from boty.drivers.xmpp.message import Message

## basic imports

import logging

## BotyXMPPBot class

class BotyXMPPBot(BotBase):

    def __init__(self, cfg, name="boty-xmpp"):
        BotBase.__init__(self, cfg, name=name)
        self.xmpp = sleekxmpp.clientxmpp.ClientXMPP(cfg.user, cfg.password)
        self.xmpp.add_event_handler("session_start", self.session_start)
        self.xmpp.add_event_handler("message", self.message)
        if cfg.openfire:
            import ssl
            self.xmpp.ssl_version = ssl.PROTOCOL_SSLv3

    def start(self, connect=True):
        BotBase.start(self, connect=False)
        if connect: self.xmpp.connect()
        self.xmpp.process()

    def session_start(self, event):
        self.xmpp.send_presence()

    def send(self, event):
        try:
            xml = event.tojabber()
            if not xml:
                raise Exception("can't convert %s to xml .. bot.send()" % what)
        except (AttributeError, TypeError):
            handle_exception()
            return
        self.xmpp.send_raw(xml)

    def outnocb(self, printto, txt, how=None, event=None, html=False, isrelayed=False, *args, **kwargs):
        """ output txt to bot. """
        #if printto and printto in self.state['joinedchannels']: outtype = 'groupchat'
        #else: outtype = "chat"
        target = printto
        txt = self.normalize(txt)
        #txt = stripcolor(txt)
        repl = Message(event)
        repl.to = target
        repl.type = (event and event.type) or "chat"
        repl.txt = txt
        if html:
            repl.html = txt
        logging.debug("%s - reply is %s" % (self.cfg.name, repl.dump()))
        if not repl.type: repl.type = 'normal'
        logging.debug("%s - sxmpp - out - %s - %s" % (self.cfg.name, printto, unicode(txt)))
        self.send(repl)

    def message(self, data):
        """ message handler. """   
        m = Message()
        m.parse(data, self)
        if m.type == 'groupchat' and m.subject:
            logging.debug("%s - checking topic" % self.cfg.name)
            self.topiccheck(m)
            nm = Message(m)   
            callbacks.check(self, nm)
            return
        if m.isresponse:
            logging.debug("%s - message is a response" % self.cfg.name)
            return
        jid = None
        m.origjid = m.jid
        if self.cfg.user in m.jid or (m.groupchat and self.cfg.nick == m.nick):
            logging.debug("%s - message to self .. ignoring" % self.cfg.name)
            return 0
        if self.cfg.fulljids and not m.msg:
            utarget = self.userhosts.get(m.nick)
            if utarget: m.userhost = m.jid = m.auth = stripped(utarget)
            else: m.userhost = m.jid
        if m.msg: m.userhost = stripped(m.userhost)
        logging.debug("using %s as userhost" % m.userhost)
        m.dontbind = False
        self.put(m)
        






# boty/plugs/version.py
#
#

""" echo boty version. """

## jsb import

from jsb.lib.config import getmainconfig
from jsb.lib.commands import cmnds
from jsb.lib.aliases import setalias

## version command

def handle_boty_version(bot, ievent):
    """ no arguments - show bot's version. """
    from boty.version import getversion
    version = getversion(bot.type.upper())
    cfg = getmainconfig()
    if cfg.dbenable: version += " " + cfg.dbtype.upper()
    try: 
        from mercurial import context, hg, node, repo, ui
        repository = hg.repository(ui.ui(), '.')
        ctx = context.changectx(repository)
        tip = str(ctx.rev())
    except: tip = None
    if tip: version2 = version + " HG " + tip
    else: version2 = version
    ievent.reply(version2)  

cmnds.add("version", handle_boty_version, ["OPER", "USER", "GUEST"])
setalias("v", "version")


"""
    SleekXMPP: The Sleek XMPP Library
    Copyright (C) 2010  Nathanael C. Fritz
    This file is part of SleekXMPP.

    See the file LICENSE for copying permission.
"""

import sys, os
sys.path.append(os.sep.join(os.path.abspath(__file__).split(os.sep)[:-1]))

from basexmpp import BaseXMPP
from clientxmpp import ClientXMPP
from componentxmpp import ComponentXMPP
from stanza import Message, Presence, Iq
from xmlstream.handler import *
from xmlstream import XMLStream, RestartStream
from xmlstream.matcher import *
from xmlstream.stanzabase import StanzaBase, ET

from version import __version__, __version_info__



# boty/version.py
#
#

""" version related stuff. """

## defines

version = "0.1"

## getversion function

def getversion(txt=""):
    """ return a version string. """
    return "BOTY %s %s" % (version, txt)



# jsb/boot.py
#
#

""" admin related data and functions. """

## basic imports

import logging
import os
import sys

## paths

sys.path.insert(0, os.getcwd())
sys.path.insert(0, os.getcwd() + os.sep + '..')

## defines

def boot(*args, **kwargs):
    logging.warn("BOTY BOOT")
    import jsb.utils.trace
    jsb.utils.trace.stopmarkers.append("boty")
    import jsb.lib.boot 
    jsb.lib.boot.plugin_packages.extend(['boty.plugs'])
    jsb.lib.boot.default_plugins.append("boty.plugs.version")
    logging.warn("booting with %s" % str(jsb.lib.boot.plugin_packages))
    jsb.lib.boot.boot(*args, **kwargs)



#!/usr/bin/env python
#
#

target = "boty" # BHJTW change this to /var/cache/jsb on debian

import os

try: from setuptools import setup
except: print "i need setuptools to properly install BOTY" ; os._exit(1)

upload = []

def uploadfiles(dir):
    upl = []
    if not os.path.isdir(dir): print "%s does not exist" % dir ; os._exit(1)
    for file in os.listdir(dir):
        if not file or file.startswith('.'):
            continue
        d = dir + os.sep + file
        if not os.path.isdir(d):
            if file.endswith(".pyc"):
                continue
            upl.append(d)
    return upl

def uploadlist(dir):
    upl = []

    for file in os.listdir(dir):
        if not file or file.startswith('.'):
            continue
        d = dir + os.sep + file
        if os.path.isdir(d):   
            upl.extend(uploadlist(d))
        else:
            if file.endswith(".pyc"):
                continue
            upl.append(d)

    return upl

setup(
    name='boty',
    version='0.1.1',
    url='http://boty.googlecode.com/',
    download_url="http://code.google.com/p/boty/downloads", 
    author='Bart Thate',
    author_email='bthate@gmail.com',
    description='Time Flies',
    license='MIT',
    include_package_data=True,
    zip_safe=False,
    scripts=['bin/boty',
             'bin/boty-xmpp'],
    packages = [ 'boty',
                 'boty/drivers',
                 'boty/drivers/xmpp',
                 'boty/lib',
                 'boty/plugs',
                 'boty/contrib/',
                 'boty/contrib/sleekxmpp',
                 'boty/contrib/sleekxmpp/stanza',   
                 'boty/contrib/sleekxmpp/test',     
                 'boty/contrib/sleekxmpp/roster',   
                 'boty/contrib/sleekxmpp/xmlstream',
                 'boty/contrib/sleekxmpp/xmlstream/matcher',
                 'boty/contrib/sleekxmpp/xmlstream/handler',
                 'boty/contrib/sleekxmpp/plugins',
                 'boty/contrib/sleekxmpp/plugins/xep_0004',
                 'boty/contrib/sleekxmpp/plugins/xep_0004/stanza',
                 'boty/contrib/sleekxmpp/plugins/xep_0009',
                 'boty/contrib/sleekxmpp/plugins/xep_0009/stanza',
                 'boty/contrib/sleekxmpp/plugins/xep_0030',
                 'boty/contrib/sleekxmpp/plugins/xep_0030/stanza',
                 'boty/contrib/sleekxmpp/plugins/xep_0050',
                 'boty/contrib/sleekxmpp/plugins/xep_0059',
                 'boty/contrib/sleekxmpp/plugins/xep_0060',
                 'boty/contrib/sleekxmpp/plugins/xep_0060/stanza',
                 'boty/contrib/sleekxmpp/plugins/xep_0066',
                 'boty/contrib/sleekxmpp/plugins/xep_0078',
                 'boty/contrib/sleekxmpp/plugins/xep_0085',
                 'boty/contrib/sleekxmpp/plugins/xep_0086',
                 'boty/contrib/sleekxmpp/plugins/xep_0092',
                 'boty/contrib/sleekxmpp/plugins/xep_0128',
                 'boty/contrib/sleekxmpp/plugins/xep_0199',
                 'boty/contrib/sleekxmpp/plugins/xep_0202',
                 'boty/contrib/sleekxmpp/plugins/xep_0203',
                 'boty/contrib/sleekxmpp/plugins/xep_0224',
                 'boty/contrib/sleekxmpp/plugins/xep_0249',
                 'boty/contrib/sleekxmpp/features',
                 'boty/contrib/sleekxmpp/features/feature_mechanisms',
                 'boty/contrib/sleekxmpp/features/feature_mechanisms/stanza',
                 'boty/contrib/sleekxmpp/features/feature_starttls',
                 'boty/contrib/sleekxmpp/features/feature_bind',   
                 'boty/contrib/sleekxmpp/features/feature_session',
                 'boty/contrib/sleekxmpp/thirdparty',
                 'boty/contrib/sleekxmpp/thirdparty/suelta',
                 'boty/contrib/sleekxmpp/thirdparty/suelta/mechanisms',
                 ],
    long_description = """ -=- always wanted to be a bird -=- """,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Environment :: Other Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Topic :: Communications :: Chat',
        'Topic :: Software Development :: Libraries :: Python Modules'],
    requires=['jsb', 
               'dnspython'
             ]
)
